/*
 *   Copyright 2008 Engineering Ingegneria Informatica S.p.A.

    This file is part of Spago4Q.

    Spago4Q is free software; you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published 
    by the Free Software Foundation; either version 3 of the License, or
    any later version.

    Spago4Q is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
package it.eng;

import java.math.BigDecimal;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.util.ArrayList;

import net.sf.jasperreports.engine.JRDefaultScriptlet;
import net.sf.jasperreports.engine.JRScriptletException;
import net.sf.jasperreports.renderers.JCommonDrawableRenderer;

import org.jfree.chart.JFreeChart;

public class ReqVariabilityMin extends JRDefaultScriptlet{

	private Connection dbConnection;
	private PreparedStatement stmt = null;
	private ResultSet rs = null;
	private ReportUtilities ru;

    private String parArea="";
    private String parProject="";
    private String parYear="";
    private String parMonth="";
    private String parCustomer="";
    private String parMethod="";
	
	private final int idKPI = 25;


	public void afterReportInit() throws JRScriptletException {

		try {
			// get db connection
			dbConnection = (Connection) this.getParameterValue("REPORT_CONNECTION");

			ru=new ReportUtilities(dbConnection); 

			// set idKPI


			// get meterChart value
			BigDecimal value = this.calculateValue(idKPI);

			// calculate kpi threshold
			int thresholdType = Integer.parseInt((String) this.getParameterValue("ParThresholdType"));
			int idUser = Integer.parseInt((String) this.getParameterValue("ParUser"));
			int idThreshold = ru.calculateThreshold(thresholdType, idUser,idKPI);

			// get meterChart title
			String title = ru.getKPITitle(idKPI);

			ArrayList<Pair> subs=ru.getSubtitles(parArea, parProject, parCustomer, parMethod);
			
			Pair year=null;
			Pair month=null;
			if(parYear.equalsIgnoreCase("0"))year=new Pair("Year","All Years");
			else year=new Pair("Year", parYear);  
			
			if(parMonth.equalsIgnoreCase("0"))month=new Pair("Month","All Monthes");
			else month=new Pair("Month", parMonth);  				
			
			subs.add(year);
			subs.add(month);
			
			// create meter chart
			JFreeChart meterchart = ru.createMeterChart(value, title, idThreshold,subs);
			this.setVariableValue("Chart_meter", new JCommonDrawableRenderer(
					meterchart));

		} catch (Exception e) {
			throw new JRScriptletException(e);
		}
	}

	private BigDecimal calculateValue(int pIdKPI) throws JRScriptletException {
		BigDecimal value = new BigDecimal(0);
		try {
			
			
			parMonth = (String) this.getParameterValue("MonthPar");
			parYear = (String) this.getParameterValue("YearPar");
			parArea = (String) this.getParameterValue("AreaPar");
			parProject = (String) this.getParameterValue("ProjectPar");
			parCustomer= (String) this.getParameterValue("CustomerPar");
			parMethod= (String) this.getParameterValue("MethodPar");
			
			String query = "select min(ft.variability) as value "
				+ " from ft_agg_req_variability ft, dt_time as dt, dt_project dj "
				+ " where ft.id_time = dt.id_time " 
				+ " and ft.id_project = dj.id_project";



			String queryPeriod = ru.buildPeriod(parYear, parMonth);
			String queryProfile = ru.buildProfile(parArea, parProject,"dj","ft");
			String queryCustomer = ru.buildCustomerMethod(parCustomer, parMethod,"dj","dj");

			stmt = dbConnection.prepareStatement(query + queryPeriod + queryProfile);
			System.out.println("query: " +query + queryPeriod + queryProfile + queryCustomer);

			stmt.execute();

			rs = stmt.executeQuery();
			if (rs.next()) {
				value = rs.getBigDecimal("value");
			}
		} catch (Exception e) {
			throw new JRScriptletException(e);
		}
		if (value == null) value = BigDecimal.valueOf(0);
		return value;
	}


}
